@@ -109,7 +109,7 @@ END
    ($stdout,$stderr)=$handle->cmd(
       'sudo yum -y install php55 php55-curl php55-gd php55-gmp '.
       'php55-intl php55-json php55-opcache php55-mysqlnd '.
-      'php55-mbstring php55-devel php55-fpm openssl-devel',
+      'php55-mbstring php55-devel php55-fpm openssl-devel re2c',
       '__display__');
    ($stdout,$stderr)=$handle->cmd(
       "sudo yum -y groupinstall 'Development tools'",'__display__');
@@ -225,7 +225,7 @@ print "\n\n\n\n\n\n\nWE SHOULD HAVE INSTALLED MARIADB=$stdout<==\n\n\n\n\n\n\n";
    ($stdout,$stderr)=$handle->cwd($nginx);
    ($stdout,$stderr)=$handle->cmd("sudo mkdir -vp objs/lib",'__display__');
    ($stdout,$stderr)=$handle->cwd("objs/lib");
-   my $pcre='pcre-8.38';
+   my $pcre='pcre-8.40';
    my $checksum='';
    foreach my $cnt (1..3) {
       ($stdout,$stderr)=$handle->cmd("sudo wget --random-wait --progress=dot ".
@@ -241,24 +241,25 @@ print "\n\n\n\n\n\n\nWE SHOULD HAVE INSTALLED MARIADB=$stdout<==\n\n\n\n\n\n\n";
    $zlib_ver=~s/^.*? source code, version (\d+\.\d+\.\d+).*$/$1/s;
    $sha__256=~s/^.*?SHA-256 hash [<]tt[>](.*?)[<][\/]tt[>].*$/$1/s;
    foreach my $count (1..3) {
-      ($stdout,$stderr)=$handle->cmd("wget --random-wait --progress=dot ".
+      ($stdout,$stderr)=$handle->cmd("sudo wget --random-wait --progress=dot ".
          "http://zlib.net/zlib-$zlib_ver.tar.gz",'__display__');
       $checksum=$sha__256;
       ($stdout,$stderr)=$handle->cmd(
-         "sha256sum -c - <<<\"$checksum zlib-$zlib_ver.tar.gz\"",
+         "sudo sha256sum -c - <<<\"$checksum zlib-$zlib_ver.tar.gz\"",
          '__display__');
       unless ($stderr) {
          print(qq{ + CHECKSUM Test for zlib-$zlib_ver *PASSED* \n});
          last
       } elsif ($count>=3) {
-         print "FATAL ERROR! : CHECKSUM Test for zlib-$zlib_ver.tar.gz *FAILED* ",
+         print "FATAL ERROR! : CHECKSUM Test for ".
+               "zlib-$zlib_ver.tar.gz *FAILED* ",
                "after $count attempts\n";
          &Net::FullAuto::FA_Core::cleanup;
       }
-      ($stdout,$stderr)=$handle->cmd("rm -rvf zlib-$zlib_ver.tar.gz",
+      ($stdout,$stderr)=$handle->cmd("sudo rm -rvf zlib-$zlib_ver.tar.gz",
          '__display__');
    }
-   ($stdout,$stderr)=$handle->cmd("tar xvf zlib-$zlib_ver.tar.gz",
+   ($stdout,$stderr)=$handle->cmd("sudo tar xvf zlib-$zlib_ver.tar.gz",
       '__display__');
    my $ossl='openssl-1.0.2h';
    foreach my $count (1..3) {
@@ -284,7 +285,7 @@ print "\n\n\n\n\n\n\nWE SHOULD HAVE INSTALLED MARIADB=$stdout<==\n\n\n\n\n\n\n";
                   '--conf-path=/usr/local/nginx/nginx.conf '.
                   '--pid-path=/usr/local/nginx/nginx.pid '.
                   "--with-http_ssl_module --with-pcre=objs/lib/$pcre ".
-                  "--with-zlib=objs/lib/$zlib";
+                  "--with-zlib=objs/lib/zlib-$zlib_ver";
    ($stdout,$stderr)=$handle->cmd($make_nginx,'__display__');
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i 's/-Werror //' ./objs/Makefile");
